import * as react from 'react';
import { Text as Text$1 } from 'hast';

declare const SYNTAX_HIGHLIGHT_STYLES: readonly ["a11yDark", "a11yDarkMin", "a11yLight", "a11yLightMin", "agate", "agateMin", "anOldHope", "anOldHopeMin", "androidstudio", "androidstudioMin", "arduinoLight", "arduinoLightMin", "arta", "artaMin", "ascetic", "asceticMin", "atomOneDark", "atomOneDarkMin", "atomOneDarkReasonable", "atomOneDarkReasonableMin", "atomOneLight", "atomOneLightMin", "brownPaper", "brownPaperMin", "codepenEmbed", "codepenEmbedMin", "colorBrewer", "colorBrewerMin", "dark", "darkMin", "defaultMin", "defaultStyle", "devibeans", "devibeansMin", "docco", "doccoMin", "far", "farMin", "felipec", "felipecMin", "foundation", "foundationMin", "github", "githubDark", "githubDarkDimmed", "githubDarkDimmedMin", "githubDarkMin", "githubMin", "gml", "gmlMin", "googlecode", "googlecodeMin", "gradientDark", "gradientDarkMin", "gradientLight", "gradientLightMin", "grayscale", "grayscaleMin", "hybrid", "hybridMin", "idea", "ideaMin", "intellijLight", "intellijLightMin", "irBlack", "irBlackMin", "isblEditorDark", "isblEditorDarkMin", "isblEditorLight", "isblEditorLightMin", "kimbieDark", "kimbieDarkMin", "kimbieLight", "kimbieLightMin", "lightfair", "lightfairMin", "lioshi", "lioshiMin", "magula", "magulaMin", "monoBlue", "monoBlueMin", "monokai", "monokaiMin", "monokaiSublime", "monokaiSublimeMin", "nightOwl", "nightOwlMin", "nnfxDark", "nnfxDarkMin", "nnfxLight", "nnfxLightMin", "nord", "nordMin", "obsidian", "obsidianMin", "pandaSyntaxDark", "pandaSyntaxDarkMin", "pandaSyntaxLight", "pandaSyntaxLightMin", "paraisoDark", "paraisoDarkMin", "paraisoLight", "paraisoLightMin", "pojoaque", "pojoaqueMin", "purebasic", "purebasicMin", "qtcreatorDark", "qtcreatorDarkMin", "qtcreatorLight", "qtcreatorLightMin", "rainbow", "rainbowMin", "routeros", "routerosMin", "schoolBook", "schoolBookMin", "shadesOfPurple", "shadesOfPurpleMin", "srcery", "srceryMin", "stackoverflowDark", "stackoverflowDarkMin", "stackoverflowLight", "stackoverflowLightMin", "sunburst", "sunburstMin", "tokyoNightDark", "tokyoNightDarkMin", "tokyoNightLight", "tokyoNightLightMin", "tomorrowNightBlue", "tomorrowNightBlueMin", "tomorrowNightBright", "tomorrowNightBrightMin", "vs", "vs2015", "vs2015Min", "vsMin", "xcode", "xcodeMin", "xt256", "xt256Min"];
type SyntaxHighlightStyle = (typeof SYNTAX_HIGHLIGHT_STYLES)[number];

type Text = Text$1;
type Span = {
    type: 'element';
    tagName: 'span';
    properties: {
        className: Array<string>;
    };
    children: Array<Span | Text>;
};

declare const SUPPORTED_LANGUAGES: readonly ["1c", "abnf", "accesslog", "actionscript", "ada", "angelscript", "apache", "applescript", "arcade", "arduino", "armasm", "asciidoc", "aspectj", "autohotkey", "autoit", "avrasm", "awk", "axapta", "bash", "basic", "bnf", "brainfuck", "c", "cal", "capnproto", "ceylon", "clean", "clojure-repl", "clojure", "cmake", "coffeescript", "coq", "cos", "cpp", "crmsh", "crystal", "csharp", "csp", "css", "d", "dart", "delphi", "diff", "django", "dns", "dockerfile", "dos", "dsconfig", "dts", "dust", "ebnf", "elixir", "elm", "erb", "erlang-repl", "erlang", "excel", "fix", "flix", "fortran", "fsharp", "gams", "gauss", "gcode", "gherkin", "glsl", "gml", "go", "golo", "gradle", "graphql", "groovy", "haml", "handlebars", "haskell", "haxe", "hsp", "http", "hy", "inform7", "ini", "irpf90", "isbl", "java", "javascript", "jboss-cli", "json", "julia-repl", "julia", "kotlin", "lasso", "latex", "ldif", "leaf", "less", "lisp", "livecodeserver", "livescript", "llvm", "lsl", "lua", "makefile", "markdown", "mathematica", "matlab", "maxima", "mel", "mercury", "mipsasm", "mizar", "mojolicious", "monkey", "moonscript", "n1ql", "nestedtext", "nginx", "nim", "nix", "node-repl", "nsis", "objectivec", "ocaml", "openscad", "oxygene", "parser3", "perl", "pf", "pgsql", "php-template", "php", "plaintext", "pony", "powershell", "processing", "profile", "prolog", "properties", "protobuf", "puppet", "purebasic", "python-repl", "python", "q", "qml", "r", "reasonml", "rib", "roboconf", "routeros", "rsl", "ruby", "ruleslanguage", "rust", "sas", "scala", "scheme", "scilab", "scss", "shell", "smali", "smalltalk", "sml", "sqf", "sql", "stan", "stata", "step21", "stylus", "subunit", "swift", "taggerscript", "tap", "tcl", "thrift", "tp", "twig", "typescript", "vala", "vbnet", "vbscript-html", "vbscript", "verilog", "vhdl", "vim", "wasm", "wren", "x86asm", "xl", "xml", "xquery", "yaml", "zephir"];
type SupportedLanguage = (typeof SUPPORTED_LANGUAGES)[number];

/** The children returned by the {@linkcode lowlight.highlight} function */
type Tree = Array<Span | Text>;
/** A node in the {@linkcode Tree} */
type Node = Span | Text;

type SyntaxHighlighterProps = {
    language?: SupportedLanguage;
    styleName?: SyntaxHighlightStyle;
    wrapLines?: boolean;
    children: string;
};
declare const SyntaxHighlighter: ({ children, wrapLines, language, styleName, }: SyntaxHighlighterProps) => react.JSX.Element;

export { type Node, SUPPORTED_LANGUAGES, SYNTAX_HIGHLIGHT_STYLES, type SupportedLanguage, type SyntaxHighlightStyle, SyntaxHighlighter, type SyntaxHighlighterProps, type Tree };
